#!/usr/bin/env node
const program = require('commander');
const parse = require('yargs-parser');
const getCliOptions = require('../dist/utils/getCliOptions');
const build = require('../dist/commands/build');
const log = require('../dist/utils/log');

program
  .allowUnknownOption()
  .option('--config <config>', 'use custom config')
  .parse(process.argv);

(async () => {
  process.env.NODE_ENV = 'production';
  const cliOptions = getCliOptions(program);
  const rawArgv = parse(process.argv.slice(2), { configuration: {'strip-dashed': true }});
  // ignore _ in rawArgv
  delete rawArgv._;
  try {
    await build({
      args: { ...rawArgv, ...cliOptions },
    });
  } catch (err) {
    log.error(err.message);
    console.error(err);
    process.exit(1);
  }
})();
